==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/SimpleLogger.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SIMPLE_LOGGER_H_
#define _D_SIMPLE_LOGGER_H_

#include "Logger.h"

class SimpleLogger:public Logger {
private:
  void writeFile(int level, const char* msg, va_list ap, Exception* e = 0) const;
  void writeHeader(FILE* file, string date, string level) const;
  void writeLog(FILE* file, int level, const char* msg, va_list ap, Exception* e = 0) const;
  FILE* file;
  int stdoutField;
public:
  SimpleLogger(FILE* logfile = 0);
  ~SimpleLogger();

  void openFile(const string& filename);
  void closeFile();
  virtual void debug(const char* msg, ...) const;
  virtual void debug(const char* msg, Exception* ex, ...) const;
  virtual void info(const char* msg, ...) const;
  virtual void info(const char* msg, Exception* ex, ...) const;
  virtual void notice(const char* msg, ...) const;
  virtual void notice(const char* msg, Exception* ex, ...) const;
  virtual void warn(const char* msg, ...) const;
  virtual void warn(const char* msg, Exception* ex, ...) const;
  virtual void error(const char* msg, ...) const;
  virtual void error(const char* msg, Exception* ex, ...) const;

  void setStdout(int level, bool enabled);
};

#endif // _D_SIMPLE_LOGGER_H_

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/SimpleLogger.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SIMPLE_LOGGER_H_
#define _D_SIMPLE_LOGGER_H_

#include "Logger.h"

class SimpleLogger:public Logger {
private:
  void writeFile(int level, const char* msg, va_list ap, Exception* e = 0) const;
  void writeHeader(FILE* file, string date, string level) const;
  void writeLog(FILE* file, int level, const char* msg, va_list ap, Exception* e = 0, bool printHeader = true) const;
  FILE* file;
  int stdoutField;
public:
  SimpleLogger(FILE* logfile = 0);
  ~SimpleLogger();

  void openFile(const string& filename);
  void closeFile();
  virtual void debug(const char* msg, ...) const;
  virtual void debug(const char* msg, Exception* ex, ...) const;
  virtual void info(const char* msg, ...) const;
  virtual void info(const char* msg, Exception* ex, ...) const;
  virtual void notice(const char* msg, ...) const;
  virtual void notice(const char* msg, Exception* ex, ...) const;
  virtual void warn(const char* msg, ...) const;
  virtual void warn(const char* msg, Exception* ex, ...) const;
  virtual void error(const char* msg, ...) const;
  virtual void error(const char* msg, Exception* ex, ...) const;

  void setStdout(int level, bool enabled);
};

#endif // _D_SIMPLE_LOGGER_H_
